@@ -16,14 +16,14 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
 from .literals import (
-    ChannelStatus,
-    ComputeType,
-    DatasetActionType,
-    DatasetContentState,
-    DatasetStatus,
-    DatastoreStatus,
-    FileFormatType,
-    ReprocessingStatus,
+    ChannelStatusType,
+    ComputeTypeType,
+    DatasetActionTypeType,
+    DatasetContentStateType,
+    DatasetStatusType,
+    DatastoreStatusType,
+    FileFormatTypeType,
+    ReprocessingStatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -226,7 +226,7 @@ ChannelSummaryTypeDef = TypedDict(
     {
         "channelName": str,
         "channelStorage": "ChannelStorageSummaryTypeDef",
-        "status": ChannelStatus,
+        "status": ChannelStatusType,
         "creationTime": datetime,
         "lastUpdateTime": datetime,
         "lastMessageArrivalTime": datetime,
@@ -240,7 +240,7 @@ ChannelTypeDef = TypedDict(
         "name": str,
         "storage": "ChannelStorageTypeDef",
         "arn": str,
-        "status": ChannelStatus,
+        "status": ChannelStatusType,
         "retentionPeriod": "RetentionPeriodTypeDef",
         "creationTime": datetime,
         "lastUpdateTime": datetime,
@@ -396,7 +396,7 @@ DatasetActionSummaryTypeDef = TypedDict(
     "DatasetActionSummaryTypeDef",
     {
         "actionName": str,
-        "actionType": DatasetActionType,
+        "actionType": DatasetActionTypeType,
     },
     total=False,
 )
@@ -444,7 +444,7 @@ class DatasetContentDeliveryRuleTypeDef(
 DatasetContentStatusTypeDef = TypedDict(
     "DatasetContentStatusTypeDef",
     {
-        "state": DatasetContentState,
+        "state": DatasetContentStateType,
         "reason": str,
     },
     total=False,
@@ -482,7 +482,7 @@ DatasetSummaryTypeDef = TypedDict(
     "DatasetSummaryTypeDef",
     {
         "datasetName": str,
-        "status": DatasetStatus,
+        "status": DatasetStatusType,
         "creationTime": datetime,
         "lastUpdateTime": datetime,
         "triggers": List["DatasetTriggerTypeDef"],
@@ -508,7 +508,7 @@ DatasetTypeDef = TypedDict(
         "actions": List["DatasetActionTypeDef"],
         "triggers": List["DatasetTriggerTypeDef"],
         "contentDeliveryRules": List["DatasetContentDeliveryRuleTypeDef"],
-        "status": DatasetStatus,
+        "status": DatasetStatusType,
         "creationTime": datetime,
         "lastUpdateTime": datetime,
         "retentionPeriod": "RetentionPeriodTypeDef",
@@ -557,11 +557,11 @@ DatastoreSummaryTypeDef = TypedDict(
     {
         "datastoreName": str,
         "datastoreStorage": "DatastoreStorageSummaryTypeDef",
-        "status": DatastoreStatus,
+        "status": DatastoreStatusType,
         "creationTime": datetime,
         "lastUpdateTime": datetime,
         "lastMessageArrivalTime": datetime,
-        "fileFormatType": FileFormatType,
+        "fileFormatType": FileFormatTypeType,
     },
     total=False,
 )
@@ -572,7 +572,7 @@ DatastoreTypeDef = TypedDict(
         "name": str,
         "storage": "DatastoreStorageTypeDef",
         "arn": str,
-        "status": DatastoreStatus,
+        "status": DatastoreStatusType,
         "retentionPeriod": "RetentionPeriodTypeDef",
         "creationTime": datetime,
         "lastUpdateTime": datetime,
@@ -990,7 +990,7 @@ ReprocessingSummaryTypeDef = TypedDict(
     "ReprocessingSummaryTypeDef",
     {
         "id": str,
-        "status": ReprocessingStatus,
+        "status": ReprocessingStatusType,
         "creationTime": datetime,
     },
     total=False,
@@ -999,7 +999,7 @@ ReprocessingSummaryTypeDef = TypedDict(
 ResourceConfigurationTypeDef = TypedDict(
     "ResourceConfigurationTypeDef",
     {
-        "computeType": ComputeType,
+        "computeType": ComputeTypeType,
         "volumeSizeInGB": int,
     },
 )
